@@ -9,7 +9,7 @@ use Scalar::Util ();
 use strict;
 use vars qw($VERSION @EXPORT);
 
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 require Exporter;
 
@@ -238,8 +238,9 @@ sub tt_process {
 
     if (! defined($vars) && (Scalar::Util::reftype($file)||'') eq 'HASH') {
         $vars = $file;
-        $file = $self->tt_template_name;
+        $file = undef;
     }
+    $file ||= $self->tt_template_name;
     $vars ||= {};
     my $template_name = $file;
 
@@ -466,10 +467,11 @@ to load a template.
 
 =head2 tt_process
 
-This is a simple wrapper around the Template Toolkit process method.  It accepts one or two parameters,
-a template filename, and a hashref of template parameters (the template filename is optional, and will
-be autogenerated by a call to $self->tt_template_name if not provided).  The return value will be a scalar
-reference to the output of the template.
+This is a simple wrapper around the Template Toolkit process method.  It
+accepts zero, one or two parameters; an optional template filename, and an
+optional hashref of template parameters (the template filename is optional, and
+will be autogenerated by a call to $self->tt_template_name if not provided).
+The return value will be a scalar reference to the output of the template.
 
   package My::App::Browser
   sub myrunmode {
